summaryrefslogtreecommitdiff
path: root/sheetpr_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'sheetpr_test.go')
-rw-r--r--sheetpr_test.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/sheetpr_test.go b/sheetpr_test.go
index 53532e9..7c669e8 100644
--- a/sheetpr_test.go
+++ b/sheetpr_test.go
@@ -153,10 +153,10 @@ func TestSheetPrOptions(t *testing.T) {
}
}
-func TestSetSheetrOptions(t *testing.T) {
+func TestSetSheetPrOptions(t *testing.T) {
f := NewFile()
assert.NoError(t, f.SetSheetPrOptions("Sheet1", TabColor("")))
// Test SetSheetrOptions on not exists worksheet.
assert.EqualError(t, f.SetSheetPrOptions("SheetN"), "sheet SheetN is not exist")
}
@@ -153,10 +153,10 @@ func TestSheetPrOptions(t *testing.T) {
f := NewFile()
assert.NoError(t, f.SetSheetPrOptions("Sheet1", TabColor("")))
- // Test SetSheetrOptions on not exists worksheet.
+ // Test SetSheetPrOptions on not exists worksheet.
assert.EqualError(t, f.SetSheetPrOptions("SheetN"), "sheet SheetN is not exist")
}